@@ -54,7 +54,7 @@ class Payload:
             Add a dict of name value pairs to the Payload object
 
             :param  dict_:          Dictionary to be added to the Payload
-            :type   dict_:          dict(string:\*)
+            :type   dict_:          dict(string:\\*)
         """
         for f in dict_:
             self.add(f, dict_[f])
@@ -70,7 +70,7 @@ class Payload:
             Add an encoded or unencoded JSON to the payload
 
             :param  dict_:                  Custom context for the event
-            :type   dict_:                  dict(string:\*) | None
+            :type   dict_:                  dict(string:\\*) | None
             :param  encode_base64:          If the payload is base64 encoded
             :type   encode_base64:          bool
             :param  type_when_encoded:      Name of the field when encode_base64 is set
